@@ -29,7 +29,7 @@
 RecoveryJsObject::RecoveryJsObject(RestoreManager *manager)
     : QObject()
     , m_manager(manager)
-    , m_page(Q_NULLPTR)
+    , m_page(nullptr)
 {
 }
 
@@ -119,7 +119,7 @@ void RecoveryJsObject::restoreSession(const QStringList &excludeWin, const QStri
 
 void RecoveryJsObject::closeTab()
 {
-    TabbedWebView *view = qobject_cast<TabbedWebView*>(m_page->view());
+    auto *view = qobject_cast<TabbedWebView*>(m_page->view());
     if (!view) {
         return;
     }
